# TermPeriodType

Unit of time that the term is measured in. Only applicable if the value of the `termType` field is `TERMED`. 

## Enum

* `DAY` (value: `'Day'`)

* `WEEK` (value: `'Week'`)

* `MONTH` (value: `'Month'`)

* `YEAR` (value: `'Year'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


